# yellowduck


[![PyPI Latest Release](https://img.shields.io/pypi/v/yellowduck?style=for-the-badge)](https://pypi.org/project/yellowduck/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/yellowduck?style=for-the-badge)
![GitHub](https://img.shields.io/github/license/PCP55/yellowduck-dev?style=for-the-badge)
![GitHub last commit](https://img.shields.io/github/last-commit/PCP55/yellowduck-dev?style=for-the-badge)
![GitHub repo size](https://img.shields.io/github/repo-size/PCP55/yellowduck-dev?style=for-the-badge)
![Lines of code](https://img.shields.io/tokei/lines/github/PCP55/yellowduck-dev?style=for-the-badge)

## What is it?

**yellowduck** is the data science toolbox for everyone. To be precise, for the lazy man like me!

Actually, **yellowduck** is like a sandbox library for me. If I found something great I will surely add it in **yellowduck**. 

## Main Features

- Check duplicate image
- Visualize duplicate image from above
- Clean Text

In addition, you can see the next features [https://github.com/PCP55/yellowduck-dev/projects/1](here)!

## Example

Please go to this [Link](https://github.com/PCP55/yellowduck-dev/tree/main/_dev)

## Prerequisites (from A to Z)

- hashlib
- imagehash
- matplotlib
- numpy
- os
- pillow
- re

## Install

```ruby
# PyPI
pip install yellowduck
```

## Found Issues

Create New Issue [here](https://github.com/PCP55/yellowduck-dev/issues) and I will fix it as soon as I have a free time. (LOL)

---------------------------------------

> This library inspired by [kora](https://github.com/airesearch-in-th/kora/tree/master/kora), A collection of tools to make programming on Google Colab easier.